/*
 * Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 * See http://www.eu-egee.org/partners/ for details on the
 * copyright holders. 
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.glite.apel.condor;



import java.io.File;

import java.io.IOException;



import org.glite.apel.core.log.type.EventRecord;



import junit.framework.TestCase;

import junit.framework.TestSuite;



/**

 * Tests to validate the functionality of the EvemtLogParser class.

 */

public class EventLogParserTest extends TestCase {

	/*

	 * Only part of the Condor record is built

         * NB: WCT and CPU quantities appear twice in the actual job record!

	 */

    private String recordStart="MyType = \"Job\"";

    private String recordEnd="***";

    private String ClusterID="ClusterId = 11347";

    private String QDate="QDate = 1127726312";

    private String CompletionDate_1="CompletionDate = 0";

    private String Owner="Owner = \"dteam003\"";

    private String User="User = \"markc@serv03.hep.phy.cam.ac.uk\"";

    private String WCT_1="RemoteWallClockTime = 0.000000";

    private String LUC_1="LocalUserCpu = 0.000000";

    private String LSC_1="LocalSysCpu = 0.000000";

    private String RUC_1="RemoteUserCpu = 0.000000";

    private String RSC_1="RemoteSysCpu = 0.000000";

    private String Exit="ExitStatus = 0";

    private String CV="CondorVersion = \"$CondorVersion: 6.6.9 Mar 10 2005 $\"";

    private String CP="CondorPlatform = \"$CondorPlatform: I386-LINUX_RH9 $\"";

    private String ENV="Env = \"X509_USER_PROXY=/home/dteam003/.globus/.gass_cache/local/md5/c9/851d90e055c5d825d431e0f38ee476/md5/7e/69d011a40bb60c9ef1fcffcf36592e/data;GLOBUS_REMOTE_IO_URL=/home/dteam003/.lcgjm/.remote_io_ptr/remote_io_file-11365.1127726245;GLOBUS_TCP_PORT_RANGE=20000 25000;GLOBUS_LOCATION=/opt/globus;GLOBUS_GRAM_JOB_CONTACT=https://serv03.hep.phy.cam.ac.uk:20002/11365/1127726245/;GLOBUS_GRAM_MYJOB_CONTACT=URLx-nexus://serv03.hep.phy.cam.ac.uk:20003/;SCRATCH_DIRECTORY=/home/dteam003/;HOME=/home/dteam003;LOGNAME=dteam003;EDG_WL_JOBID=https://gdrb04.cern.ch:9000/BwEKpgLFaCuSZunHp1y9OQ\"";

    private String JSD="JobStartDate = 1127726314";

    private String JCSD="JobCurrentStartDate = 1127726314";

    private String LUC_2="LocalUserCpu = 0.000000";

    private String LSC_2="LocalSysCpu = 0.000000";

    private String RUC_2="RemoteUserCpu = 552.000000";

    private String RSC_2="RemoteSysCpu = 0.000000";

    private String WCT_2="RemoteWallClockTime = 602.000000";

    private String LRH="LastRemoteHost = \"farm030--hep--phy.grid.private.cam.ac.uk\"";

    private String CompletionDate_2="CompletionDate = 1127726671";



   // Quantities derived from this record

    private String cpuTime="552";

    private String jobName="11347.farm030--hep--phy.grid.private.cam.ac.uk";

    private String user="dteam003";

    private String group="dteam"; 

    private String remoteWCT="602";

    private String startTime="1127726314";

    private String stopTime="1127726671";

   

    public static junit.framework.Test suite() {

        return new TestSuite(EventLogParserTest.class);

    }



    /**

     * Constructs a dummy event record, returning it as a string.

     */

    private String constructEvent() {

        String jobInfo = ClusterID + ";;;" + QDate + ";;;" + CompletionDate_1 + ";;;" + Owner + ";;;" + User + ";;;" +

        WCT_1 + ";;;" + LUC_1 + ";;;" + LSC_1 + ";;;" + RUC_1 + ";;;" + RSC_1 + ";;;" + 

        Exit + ";;;" + CV + ";;;" + CP + ";;;" + ENV + ";;;" + JSD + ";;;" + JCSD + ";;;" +

        WCT_2 + ";;;" + LUC_2 + ";;;" + LSC_2 + ";;;" + RUC_2 + ";;;" + RSC_2 + ";;;" +

        LRH + ";;;" + CompletionDate_2;

        return recordStart + ";;;" + jobInfo + ";;;" + recordEnd + ";;;";

    }



    /**

     * Checks the event parser successfully interprets an event log entry.

     */

    public void testParse() {

        String input = constructEvent();

        File tmp = null;

        try {

        	tmp = File.createTempFile("unittest", "tmp");

            tmp.deleteOnExit();

        } catch (IOException ioe) {

        	fail();

        }

        EventLogParser parser = new EventLogParser(tmp, "","");

        EventRecord record = parser.createEventRecord(input);

        assertEquals(record.getCpuDurationSeconds(), cpuTime);

        //assertEquals(record.getCpuDurationSeconds(),Integer.toString(cpuTimeSeconds));

        //assertEquals(record.getJobName(), jobName);

        assertEquals(record.getLocalUserGroup(), group);

        assertEquals(record.getLocalUserID(), user);

        //assertEquals(record.getEventDate(), mDate);

        //assertEquals(record.getEventTime(), mTime);

        //assertEquals(record.getMemoryReal(), memReal);

        //assertEquals(record.getMemoryVirtual(), memVirtual);

        assertEquals(record.getStartTimeEpoch(), startTime);

        assertEquals(record.getStopTimeEpoch(), stopTime);

        //assertEquals(record.getWallDurationSeconds(), Integer.toString(wallTime));

        assertEquals(record.getWallDurationSeconds(), remoteWCT);

    }



}

